'****************************************************************************************
'*                      Smart Home (Pic18F8722,OSC-16MHz)                               *
'**************************************************************************************** 
'----------------------------------------------------------------------------------------

START:

Device = 18F8722

Config_Start
  OSC = HS
  FCMEN = OFF                     'Fail-Safe Clock Monitor disabled
  IESO = OFF                      'Two-Speed Start-up disabled
  PWRT = OFF                      'PWRT disabled
  BOREN = SBORDIS                 'Brown-out Reset enabled in hardware only (SBOREN is disabled)
  WDT = OFF                       'WDT disabled
  WDTPS = 32768                   '1:32768
  MODE = MC                       'Microcontroller mode
  ADDRBW = ADDR16BIT              '16-bit Address Bus
  DATABW = DATA16BIT              '16-bit External Bus mode
  LPT1OSC = OFF                   'Timer1 configured for higher power operation
  MCLRE = On                      'MCLR pin enabled; RG5 input pin disabled
  STVREN = OFF                    'Stack full/underflow will cause Reset
  LVP = OFF                       'Single-Supply ICSP disabled 
  Debug = OFF                     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins
  CPD = OFF                       'Data EEPROM not code-protected
  WRTD = OFF                      'Data EEPROM not write-protected 
  EBTRB = OFF                     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads
Config_End

'Declare Xtal 16
Declare Xtal 4

'----------------------  GLCD --------------------------------------------------

Declare LCD_Type = GRAPHIC        '   - 
Declare LCD_DTPort = PORTD        '   
Declare LCD_RWPin = PORTE.7       '   RW
Declare LCD_RSPin = PORTE.4       '   RS
Declare LCD_ENPin = PORTE.3       '   E
Declare LCD_CS1Pin = PORTE.6      '   CS1
Declare LCD_CS2Pin = PORTE.5      '   CS2
Declare Internal_Font = On        '      
Cls                               '  

'----------------------   ------------------------------------------------
                                  ' (1-,0-)
TRISA = %00110001	              
TRISB = %00111001	                
TRISC = %01100011	                
TRISD = %00000000	                
TRISE = %00000011                   
TRISF = %00000010                   
TRISG = %00001111                   
TRISH = %00110000                   
TRISJ = %00000100               

ADCON0 = %00000000                '  A/D   AN0                        
ADCON1 = %00001110                ' AN0    
ADCON2 = %10110001                ' 10- (1024 )   ,                      
                                  '      16-Tosc( f<22.86MHz),
                                  '     Fosc/8( 5-20MHz)                                                                
Declare SDA_Pin PORTB.6           '  I2C
Declare SCL_Pin PORTB.7           '  I2C


'---------------------------      -------------------

INTCON.7 = 1                      '    
                                  '(1-(    )/0-)
INTCON.6 = 1                      '      
                                  '(1-(.. TMR1 - )/0-)   
INTCON.5 = 0                      '      TMR0
                                  ' (1-/0-- ) 
INTCON.4 = 1                      '     PORTB.0(INT0)(1-/0-) 
INTCON.3 = 0                      '     PORTB.4-7(1-/0-- )
                                  ' (1-    RB /0-)                                                              
Symbol TMR0IF = INTCON.2          '   TMR0
Symbol INT0IF = INTCON.1          '     PORTB.0(INT0)
Symbol RBIF = INTCON.0            '     PORTB.4-PORTB.7

INTCON2.7 = 1                     '   Pull-Up  B (1)
INTCON2.6 = 1                     '     INT0 (1- )

INTCON3.5 = 0                     '     INT3(1-/0-)
INTCON3.4 = 0                     '     INT2(1-/0-)
INTCON3.3 = 0                     '     INT1(1-/0-)
                       
PIE2.4 = 0                        '    (1-/0-)
IPR2.4 = 1                        '    (1-/0-)

'EECON1.7 = 0
'EECON1.6 = 1
'EECON1.4 = 0
'EECON1.2 = 1
'EECON1.1 = 1
'EECON1.0 = 1

'----------------------  ,      ------------
                                  
Dim X As Word                     '   
Dim Y As Word                     '   
Dim Z As Byte                     '   


'----------------------------------------------------------------------------------------

On_Hardware_Interrupt MYINT       '       myINT

'----------------------------------------------------------------------------------------
'========================================================================================
'---------------------------    ----------------------------------
'======================================================================================== 

TEST:
 
For X=0 To 255
    Print At 0,0,"Write ", Dec3 X
    EWrite X,[X]    
    DelayMS 100   
    Y = ERead X
    Print At 3,0," Read ", Dec3 Y
    DelayMS 1000
Next X

                                   
GoTo TEST



'========================================================================================
'----------------------       INT0(B0)-----

MYINT:                       

Disable                           ' disable-enable    ,
                                  '      .
Context Save                      '     

If INT0IF = 1 Then                '   -         INT0
    
    INT0IF = 0                    ' C       INT0,
                                  '        .                                                        
  
                           
EndIf                                                                 
                             
Context Restore                   '                              
Resume
Enable

'========================================================================================
'---------------------------------------------------------------------------------------- 
Include "Font.inc"                '   ,   


